aboutsummaryrefslogtreecommitdiff
path: root/src/core/telemetry_session.h
diff options
context:
space:
mode:
authorLioncash <mathew1800@gmail.com>2020-11-18 07:53:10 -0500
committerLioncash <mathew1800@gmail.com>2020-11-18 09:36:48 -0500
commit6f8a06bac58790d20dae3c1adb4de3b441f07b30 (patch)
treeef5e2942aa0aacbebb683da91ee6d4bd19ec15e9 /src/core/telemetry_session.h
parentabda36636245c416a75774165d2a5b49610952fc (diff)
patch_manager: Remove usages of the global system instance
With this, only 19 usages of the global system instance remain within the core library. We're almost there.
Diffstat (limited to 'src/core/telemetry_session.h')
-rw-r--r--src/core/telemetry_session.h18
1 files changed, 15 insertions, 3 deletions
diff --git a/src/core/telemetry_session.h b/src/core/telemetry_session.h
index 66789d4bd0..6f3d45bea0 100644
--- a/src/core/telemetry_session.h
+++ b/src/core/telemetry_session.h
@@ -7,10 +7,18 @@
#include <string>
#include "common/telemetry.h"
+namespace FileSys {
+class ContentProvider;
+}
+
namespace Loader {
class AppLoader;
}
+namespace Service::FileSystem {
+class FileSystemController;
+}
+
namespace Core {
/**
@@ -40,10 +48,14 @@ public:
* - Title file format
* - Miscellaneous settings values.
*
* @param app_loader The application loader to use to retrieve
* title-specific information.
*/
- void AddInitialInfo(Loader::AppLoader& app_loader);
+ void AddInitialInfo(Loader::AppLoader& app_loader,
+ const Service::FileSystem::FileSystemController& fsc,
+ const FileSys::ContentProvider& content_provider);
/**
* Wrapper around the Telemetry::FieldCollection::AddField method.
@@ -40,10 +48,14 @@ public:
* - Miscellaneous settings values.
*
- * @param app_loader The application loader to use to retrieve
- * title-specific information.
+ * @param app_loader The application loader to use to retrieve
+ * title-specific information.
+ * @param fsc Filesystem controller to use to retrieve info.
+ * @param content_provider Content provider to use to retrieve info.
*/